@@ -109,10 +109,10 @@ pub async fn handle_device_update(
     config: PrintNannyConfig,
 ) -> Result<PrintNannyConfig, ServiceError> {
     info!("Sending device info using config {:?}", &config);
-    let service = ApiService::new(config)?;
+    let mut service = ApiService::new(config)?;
     let new_config = service.device_setup().await?;
     info!("Success! Config updated: {:?}", &new_config);
-    Ok(new_config)
+    Ok(service.config.clone())
 }
 
 async fn handle_token_validate(
